@@ -1,3 +1,20 @@
+# Licensed to Elasticsearch B.V. under one or more contributor
+# license agreements. See the NOTICE file distributed with
+# this work for additional information regarding copyright
+# ownership. Elasticsearch B.V. licenses this file to you under
+# the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
 #! perl
 use Test::More;
 use Test::Deep;
@@ -30,17 +47,17 @@ our %Auth = ( use_https => 1, userinfo => $ENV{ES_USERINFO} );
 
 # Test https connection with correct auth, without cacert
 $ENV{ES_CXN_POOL} = 'Async::Static';
-my $es = do "es_async.pl";
+my $es = do "es_async.pl" or die( $@ || $! );
 ok wait_for( $es->cluster->health ),
     "$ENV{ES_CXN} - Non-cert HTTPS with auth, cxn static";
 
 $ENV{ES_CXN_POOL} = 'Async::Sniff';
-$es = do "es_async.pl";
+$es = do "es_async.pl" or die( $@ || $! );
 ok wait_for( $es->cluster->health ),
     "$ENV{ES_CXN} - Non-cert HTTPS with auth, cxn sniff";
 
 $ENV{ES_CXN_POOL} = 'Async::Static::NoPing';
-$es = do "es_async.pl";
+$es = do "es_async.pl" or die( $@ || $! );
 ok wait_for( $es->cluster->health ),
     "$ENV{ES_CXN} - Non-cert HTTPS with auth, cxn noping";
 
@@ -52,21 +69,21 @@ throws_ok { wait_for( $es->nodes->shutdown ) }
 # Test https connection with correct auth, with valid cacert
 $Auth{ssl_options} = ssl_options( $ENV{ES_CA_PATH} );
 
-$es = do "es_async.pl";
+$es = do "es_async.pl" or die( $@ || $! );
 
 ok wait_for( $es->cluster->health ),
     "$ENV{ES_CXN} - Valid cert HTTPS with auth";
 
 # Test invalid user credentials
 %Auth = ( userinfo => 'foobar:baz' );
-$es = do "es_async.pl";
+$es = do "es_async.pl" or die( $@ || $! );
 throws_ok { wait_for( $es->cluster->health ) }
 "Search::Elasticsearch::Error::Unauthorized", "$ENV{ES_CXN} - Bad userinfo";
 
 # Test https connection with correct auth, with invalid cacert
 $Auth{ssl_options} = ssl_options('t/lib/bad_cacert.pem');
 
-$es = do "es_async.pl";
+$es = do "es_async.pl" or die( $@ || $! );
 $ENV{ES} = "https://www.google.com";
 
 throws_ok { wait_for( $es->cluster->health ) }
